---
name: Documentation
about: Suggest a improvement to user, developer or other documentation
title: ''
labels: Documentation

---

**Description of the documentation**
A description of what area can benefit from better documentation.

**Additional details**
Add any other context or screenshots about this request.
